#ifndef STATIC_EXTERN
#define STATIC_EXTERN
namespace giac{
struct unary_function_ptr;
extern const unary_function_ptr * const  at_PERCENT;
extern const unary_function_ptr * const  at_PERCENTCHANGE;
extern const unary_function_ptr * const  at_PERCENTTOTAL;
extern const unary_function_ptr * const  at_struct_dot;
extern const unary_function_ptr * const  at_ABS;
extern const unary_function_ptr * const  at_ACOS;
extern const unary_function_ptr * const  at_ACOSH;
extern const unary_function_ptr * const  at_ACOT;
extern const unary_function_ptr * const  at_ACSC;
extern const unary_function_ptr * const  at_ADDCOL;
extern const unary_function_ptr * const  at_ADDROW;
extern const unary_function_ptr * const  at_ALOG;
extern const unary_function_ptr * const  at_ARC;
extern const unary_function_ptr * const  at_ARG;
extern const unary_function_ptr * const  at_ASEC;
extern const unary_function_ptr * const  at_ASIN;
extern const unary_function_ptr * const  at_ASINH;
extern const unary_function_ptr * const  at_ATAN;
extern const unary_function_ptr * const  at_ATANH;
extern const unary_function_ptr * const  at_Airy_Ai;
extern const unary_function_ptr * const  at_Airy_Bi;
extern const unary_function_ptr * const  at_Ans;
extern const unary_function_ptr * const  at_Archive;
extern const unary_function_ptr * const  at_BINOMIAL;
extern const unary_function_ptr * const  at_BesselI;
extern const unary_function_ptr * const  at_BesselJ;
extern const unary_function_ptr * const  at_BesselK;
extern const unary_function_ptr * const  at_BesselY;
extern const unary_function_ptr * const  at_Beta;
extern const unary_function_ptr * const  at_Bezier;
extern const unary_function_ptr * const  at_BlockDiagonal;
extern const unary_function_ptr * const  at_CEILING;
extern const unary_function_ptr * const  at_CHOOSE;
extern const unary_function_ptr * const  at_COLNORM;
extern const unary_function_ptr * const  at_COMB;
extern const unary_function_ptr * const  at_CONCAT;
extern const unary_function_ptr * const  at_COND;
extern const unary_function_ptr * const  at_CONJ;
extern const unary_function_ptr * const  at_COS;
extern const unary_function_ptr * const  at_COSH;
extern const unary_function_ptr * const  at_COT;
extern const unary_function_ptr * const  at_CROSS;
extern const unary_function_ptr * const  at_CSC;
extern const unary_function_ptr * const  at_Celsius2Fahrenheit;
extern const unary_function_ptr * const  at_Ci;
extern const unary_function_ptr * const  at_Ci0;
extern const unary_function_ptr * const  at_Circle;
extern const unary_function_ptr * const  at_ClrDraw;
extern const unary_function_ptr * const  at_ClrGraph;
extern const unary_function_ptr * const  at_ClrIO;
extern const unary_function_ptr * const  at_CopyVar;
extern const unary_function_ptr * const  at_CyclePic;
extern const unary_function_ptr * const  at_DEGXRAD;
extern const unary_function_ptr * const  at_DELCOL;
extern const unary_function_ptr * const  at_DELROW;
extern const unary_function_ptr * const  at_DET;
extern const unary_function_ptr * const  at_DISP;
extern const unary_function_ptr * const  at_DOT;
extern const unary_function_ptr * const  at_DROP;
extern const unary_function_ptr * const  at_DUP;
extern const unary_function_ptr * const  at_DelFold;
extern const unary_function_ptr * const  at_DelVar;
extern const unary_function_ptr * const  at_Det;
extern const unary_function_ptr * const  at_Dirac;
extern const unary_function_ptr * const  at_DispG;
extern const unary_function_ptr * const  at_DispHome;
extern const unary_function_ptr * const  at_DrawFunc;
extern const unary_function_ptr * const  at_DrawInv;
extern const unary_function_ptr * const  at_DrawParm;
extern const unary_function_ptr * const  at_DrawPol;
extern const unary_function_ptr * const  at_DrawSlp;
extern const unary_function_ptr * const  at_DrwCtour;
extern const unary_function_ptr * const  at_EDITMAT;
extern const unary_function_ptr * const  at_EIGENVAL;
extern const unary_function_ptr * const  at_EIGENVV;
extern const unary_function_ptr * const  at_EXP;
extern const unary_function_ptr * const  at_EXPM1;
extern const unary_function_ptr * const  at_EXPORT;
extern const unary_function_ptr * const  at_Ei;
extern const unary_function_ptr * const  at_Ei0;
extern const unary_function_ptr * const  at_Ei_f;
extern const unary_function_ptr * const  at_Eta;
extern const unary_function_ptr * const  at_Exec;
extern const unary_function_ptr * const  at_FLOOR;
extern const unary_function_ptr * const  at_FNROOT;
extern const unary_function_ptr * const  at_FP;
extern const unary_function_ptr * const  at_Factor;
extern const unary_function_ptr * const  at_Fahrenheit2Celsius;
extern const unary_function_ptr * const  at_Fill;
extern const unary_function_ptr * const  at_GETKEY;
extern const unary_function_ptr * const  at_GF;
extern const unary_function_ptr * const  at_Gamma;
extern const unary_function_ptr * const  at_Gcd;
extern const unary_function_ptr * const  at_Gcdex;
extern const unary_function_ptr * const  at_Get;
extern const unary_function_ptr * const  at_GetCalc;
extern const unary_function_ptr * const  at_GetFold;
extern const unary_function_ptr * const  at_Graph;
extern const unary_function_ptr * const  at_HMSX;
extern const unary_function_ptr * const  at_Heaviside;
extern const unary_function_ptr * const  at_IDENMAT;
extern const unary_function_ptr * const  at_IFTE;
extern const unary_function_ptr * const  at_IM;
extern const unary_function_ptr * const  at_INPUT;
extern const unary_function_ptr * const  at_INTERSECT;
extern const unary_function_ptr * const  at_INVERSE;
extern const unary_function_ptr * const  at_IP;
extern const unary_function_ptr * const  at_ISOLATE;
extern const unary_function_ptr * const  at_ITERATE;
extern const unary_function_ptr * const  at_Input;
extern const unary_function_ptr * const  at_InputStr;
extern const unary_function_ptr * const  at_Int;
extern const unary_function_ptr * const  at_Inverse;
extern const unary_function_ptr * const  at_JordanBlock;
extern const unary_function_ptr * const  at_Kronecker;
extern const unary_function_ptr * const  at_LINE;
extern const unary_function_ptr * const  at_IS_LINEAR;
extern const unary_function_ptr * const  at_LN;
extern const unary_function_ptr * const  at_LNP1;
extern const unary_function_ptr * const  at_LOG;
extern const unary_function_ptr * const  at_LQ;
extern const unary_function_ptr * const  at_LSQ;
extern const unary_function_ptr * const  at_LU;
extern const unary_function_ptr * const  at_LambertW;
extern const unary_function_ptr * const  at_LambertWs;
extern const unary_function_ptr * const  at_Li;
extern const unary_function_ptr * const  at_Line;
extern const unary_function_ptr * const  at_LineHorz;
extern const unary_function_ptr * const  at_LineTan;
extern const unary_function_ptr * const  at_LineVert;
extern const unary_function_ptr * const  at_MAKELIST;
extern const unary_function_ptr * const  at_MAKEMAT;
extern const unary_function_ptr * const  at_MANT;
extern const unary_function_ptr * const  at_MAX;
extern const unary_function_ptr * const  at_MAXREAL;
extern const unary_function_ptr * const  at_MIN;
extern const unary_function_ptr * const  at_MINREAL;
extern const unary_function_ptr * const  at_MINUS;
extern const unary_function_ptr * const  at_MOD;
extern const unary_function_ptr * const  at_MSGBOX;
extern const unary_function_ptr * const  at_NOP;
extern const unary_function_ptr * const  at_NORMALD;
extern const unary_function_ptr * const  at_NTHROOT;
extern const unary_function_ptr * const  at_NewFold;
extern const unary_function_ptr * const  at_NewPic;
extern const unary_function_ptr * const  at_Nop;
extern const unary_function_ptr * const  at_Nullspace;
extern const unary_function_ptr * const  at_OVER;
extern const unary_function_ptr * const  at_Output;
extern const unary_function_ptr * const  at_Ox_2d_unit_vector;
extern const unary_function_ptr * const  at_Ox_3d_unit_vector;
extern const unary_function_ptr * const  at_Oy_2d_unit_vector;
extern const unary_function_ptr * const  at_Oy_3d_unit_vector;
extern const unary_function_ptr * const  at_Oz_3d_unit_vector;
extern const unary_function_ptr * const  at_PERM;
extern const unary_function_ptr * const  at_PICK;
extern const unary_function_ptr * const  at_PIECEWISE;
extern const unary_function_ptr * const  at_PIXOFF;
extern const unary_function_ptr * const  at_PIXON;
extern const unary_function_ptr * const  at_POISSON;
extern const unary_function_ptr * const  at_POLYCOEF;
extern const unary_function_ptr * const  at_POLYEVAL;
extern const unary_function_ptr * const  at_POLYFORM;
extern const unary_function_ptr * const  at_POLYROOT;
extern const unary_function_ptr * const  at_POS;
extern const unary_function_ptr * const  at_PRINT;
extern const unary_function_ptr * const  at_Pause;
extern const unary_function_ptr * const  at_Phi;
extern const unary_function_ptr * const  at_Pictsize;
extern const unary_function_ptr * const  at_PopUp;
extern const unary_function_ptr * const  at_Prompt;
extern const unary_function_ptr * const  at_Psi;
extern const unary_function_ptr * const  at_Psi_minus_ln;
extern const unary_function_ptr * const  at_PtOff;
extern const unary_function_ptr * const  at_PtOn;
extern const unary_function_ptr * const  at_PtText;
extern const unary_function_ptr * const  at_PxlOff;
extern const unary_function_ptr * const  at_PxlOn;
extern const unary_function_ptr * const  at_QR;
extern const unary_function_ptr * const  at_QUAD;
extern const unary_function_ptr * const  at_QUOTE;
extern const unary_function_ptr * const  at_Quo;
extern const unary_function_ptr * const  at_RADXDEG;
extern const unary_function_ptr * const  at_RANDMAT;
extern const unary_function_ptr * const  at_RANDOM;
extern const unary_function_ptr * const  at_RANDSEED;
extern const unary_function_ptr * const  at_RANK;
extern const unary_function_ptr * const  at_RCL;
extern const unary_function_ptr * const  at_RE;
extern const unary_function_ptr * const  at_RECT;
extern const unary_function_ptr * const  at_RECURSE;
extern const unary_function_ptr * const  at_REDIM;
extern const unary_function_ptr * const  at_REPLACE;
extern const unary_function_ptr * const  at_REVERSE;
extern const unary_function_ptr * const  at_ROUND;
extern const unary_function_ptr * const  at_ROWNORM;
extern const unary_function_ptr * const  at_RPN_CASE;
extern const unary_function_ptr * const  at_RPN_FOR;
extern const unary_function_ptr * const  at_RPN_LOCAL;
extern const unary_function_ptr * const  at_RPN_WHILE;
extern const unary_function_ptr * const  at_RREF;
extern const unary_function_ptr * const  at_RandSeed;
extern const unary_function_ptr * const  at_Rank;
extern const unary_function_ptr * const  at_RclPic;
extern const unary_function_ptr * const  at_Rem;
extern const unary_function_ptr * const  at_Resultant;
extern const unary_function_ptr * const  at_RplcPic;
extern const unary_function_ptr * const  at_Rref;
extern const unary_function_ptr * const  at_SCALE;
extern const unary_function_ptr * const  at_SCALEADD;
extern const unary_function_ptr * const  at_SCHUR;
extern const unary_function_ptr * const  at_SEC;
extern const unary_function_ptr * const  at_SIGN;
extern const unary_function_ptr * const  at_SIN;
extern const unary_function_ptr * const  at_SINH;
extern const unary_function_ptr * const  at_SIZE;
extern const unary_function_ptr * const  at_SORT;
extern const unary_function_ptr * const  at_SPECNORM;
extern const unary_function_ptr * const  at_SPECRAD;
extern const unary_function_ptr * const  at_SUB;
extern const unary_function_ptr * const  at_SVD;
extern const unary_function_ptr * const  at_SVL;
extern const unary_function_ptr * const  at_SWAP;
extern const unary_function_ptr * const  at_SWAPCOL;
extern const unary_function_ptr * const  at_SWAPROW;
extern const unary_function_ptr * const  at_SetFold;
extern const unary_function_ptr * const  at_Si;
extern const unary_function_ptr * const  at_SiCi_f;
extern const unary_function_ptr * const  at_SiCi_g;
extern const unary_function_ptr * const  at_SortA;
extern const unary_function_ptr * const  at_SortD;
extern const unary_function_ptr * const  at_StoPic;
extern const unary_function_ptr * const  at_Store;
extern const unary_function_ptr * const  at_Sum;
extern const unary_function_ptr * const  at_TAN;
extern const unary_function_ptr * const  at_TANH;
extern const unary_function_ptr * const  at_TAYLOR;
extern const unary_function_ptr * const  at_TRACE;
extern const unary_function_ptr * const  at_TRN;
extern const unary_function_ptr * const  at_TRUNCATE;
extern const unary_function_ptr * const  at_TeX;
extern const unary_function_ptr * const  at_UNION;
extern const unary_function_ptr * const  at_UTPC;
extern const unary_function_ptr * const  at_UTPF;
extern const unary_function_ptr * const  at_UTPN;
extern const unary_function_ptr * const  at_UTPT;
extern const unary_function_ptr * const  at_Unarchiv;
extern const unary_function_ptr * const  at_VAS;
extern const unary_function_ptr * const  at_VAS_positive;
extern const unary_function_ptr * const  at_VIEWS;
extern const unary_function_ptr * const  at_WAIT;
extern const unary_function_ptr * const  at_XHMS;
extern const unary_function_ptr * const  at_XPON;
extern const unary_function_ptr * const  at_Zeta;
extern const unary_function_ptr * const  at_ZoomRcl;
extern const unary_function_ptr * const  at_ZoomSto;
extern const unary_function_ptr * const  at_a2q;
extern const unary_function_ptr * const  at_abcuv;
extern const unary_function_ptr * const  at_about;
extern const unary_function_ptr * const  at_abs;
extern const unary_function_ptr * const  at_abscissa;
extern const unary_function_ptr * const  at_accumulate_head_tail;
extern const unary_function_ptr * const  at_acos;
extern const unary_function_ptr * const  at_acos2asin;
extern const unary_function_ptr * const  at_acos2atan;
extern const unary_function_ptr * const  at_acosh;
extern const unary_function_ptr * const  at_acot;
extern const unary_function_ptr * const  at_acoth;
extern const unary_function_ptr * const  at_acsc;
extern const unary_function_ptr * const  at_add;
extern const unary_function_ptr * const  at_add_arc;
extern const unary_function_ptr * const  at_add_autosimplify;
extern const unary_function_ptr * const  at_add_edge;
extern const unary_function_ptr * const  at_add_language;
extern const unary_function_ptr * const  at_add_vertex;
extern const unary_function_ptr * const  at_additionally;
extern const unary_function_ptr * const  at_adjacency_matrix;
extern const unary_function_ptr * const  at_adjoint_matrix;
extern const unary_function_ptr * const  at_affix;
extern const unary_function_ptr * const  at_alg;
extern const unary_function_ptr * const  at_algsubs;
extern const unary_function_ptr * const  at_algvar;
extern const unary_function_ptr * const  at_allpairs_distance;
extern const unary_function_ptr * const  at_alog10;
extern const unary_function_ptr * const  at_alors;
extern const unary_function_ptr * const  at_altitude;
extern const unary_function_ptr * const  at_and;
extern const unary_function_ptr * const  at_andsto;
extern const unary_function_ptr * const  at_angle;
extern const unary_function_ptr * const  at_angleat;
extern const unary_function_ptr * const  at_angleatraw;
extern const unary_function_ptr * const  at_animate;
extern const unary_function_ptr * const  at_animate3d;
extern const unary_function_ptr * const  at_animation;
extern const unary_function_ptr * const  at_ans;
extern const unary_function_ptr * const  at_antiprism_graph;
extern const unary_function_ptr * const  at_append;
extern const unary_function_ptr * const  at_apply;
extern const unary_function_ptr * const  at_approx;
extern const unary_function_ptr * const  at_arc;
extern const unary_function_ptr * const  at_arcLen;
extern const unary_function_ptr * const  at_archive;
extern const unary_function_ptr * const  at_arclen;
extern const unary_function_ptr * const  at_area;
extern const unary_function_ptr * const  at_areaat;
extern const unary_function_ptr * const  at_areaatraw;
extern const unary_function_ptr * const  at_areaplot;
extern const unary_function_ptr * const  at_arg;
extern const unary_function_ptr * const  at_array;
extern const unary_function_ptr * const  at_array_sto;
extern const unary_function_ptr * const  at_arrivals;
extern const unary_function_ptr * const  at_articulation_points;
extern const unary_function_ptr * const  at_as_function_of;
extern const unary_function_ptr * const  at_asc;
extern const unary_function_ptr * const  at_asec;
extern const unary_function_ptr * const  at_asin;
extern const unary_function_ptr * const  at_asin2acos;
extern const unary_function_ptr * const  at_asin2atan;
extern const unary_function_ptr * const  at_asinh;
extern const unary_function_ptr * const  at_assert;
extern const unary_function_ptr * const  at_assign;
extern const unary_function_ptr * const  at_assign_edge_weights;
extern const unary_function_ptr * const  at_assume;
extern const unary_function_ptr * const  at_atan;
extern const unary_function_ptr * const  at_atan2;
extern const unary_function_ptr * const  at_atan2acos;
extern const unary_function_ptr * const  at_atan2asin;
extern const unary_function_ptr * const  at_atanh;
extern const unary_function_ptr * const  at_atrig2ln;
extern const unary_function_ptr * const  at_augment;
extern const unary_function_ptr * const  at_auto_correlation;
extern const unary_function_ptr * const  at_autosimplify;
extern const unary_function_ptr * const  at_avance;
extern const unary_function_ptr * const  at_avgRC;
extern const unary_function_ptr * const  at_back;
extern const unary_function_ptr * const  at_background;
extern const unary_function_ptr * const  at_backward;
extern const unary_function_ptr * const  at_baisse_crayon;
extern const unary_function_ptr * const  at_bar_plot;
extern const unary_function_ptr * const  at_barplot;
extern const unary_function_ptr * const  at_bartlett_hann_window;
extern const unary_function_ptr * const  at_barycenter;
extern const unary_function_ptr * const  at_basis;
extern const unary_function_ptr * const  at_batons;
extern const unary_function_ptr * const  at_bellman_ford;
extern const unary_function_ptr * const  at_bernoulli;
extern const unary_function_ptr * const  at_besselI;
extern const unary_function_ptr * const  at_besselJ;
extern const unary_function_ptr * const  at_besselK;
extern const unary_function_ptr * const  at_besselY;
extern const unary_function_ptr * const  at_betad;
extern const unary_function_ptr * const  at_betad_cdf;
extern const unary_function_ptr * const  at_betad_icdf;
extern const unary_function_ptr * const  at_betavariate;
extern const unary_function_ptr * const  at_bezier;
extern const unary_function_ptr * const  at_bezout_entiers;
extern const unary_function_ptr * const  at_biconnected_components;
extern const unary_function_ptr * const  at_bin;
extern const unary_function_ptr * const  at_binomial;
extern const unary_function_ptr * const  at_binomial_cdf;
extern const unary_function_ptr * const  at_binomial_icdf;
extern const unary_function_ptr * const  at_binprint;
extern const unary_function_ptr * const  at_bipartite_matching;
extern const unary_function_ptr * const  at_bisector;
extern const unary_function_ptr * const  at_bit_depth;
extern const unary_function_ptr * const  at_bitand;
extern const unary_function_ptr * const  at_bitmap;
extern const unary_function_ptr * const  at_bitnot;
extern const unary_function_ptr * const  at_bitor;
extern const unary_function_ptr * const  at_bitxor;
extern const unary_function_ptr * const  at_black;
extern const unary_function_ptr * const  at_blackman_harris_window;
extern const unary_function_ptr * const  at_blackman_window;
extern const unary_function_ptr * const  at_blockmatrix;
extern const unary_function_ptr * const  at_blockmatrix_mult_size;
extern const unary_function_ptr * const  at_blue;
extern const unary_function_ptr * const  at_bohman_window;
extern const unary_function_ptr * const  at_bool;
extern const unary_function_ptr * const  at_border;
extern const unary_function_ptr * const  at_bounded_function;
extern const unary_function_ptr * const  at_boxwhisker;
extern const unary_function_ptr * const  at_break;
extern const unary_function_ptr * const  at_breakpoint;
extern const unary_function_ptr * const  at_bvpsolve;
extern const unary_function_ptr * const  at_c1oc2;
extern const unary_function_ptr * const  at_c1op2;
extern const unary_function_ptr * const  at_cFactor;
extern const unary_function_ptr * const  at_cSolve;
extern const unary_function_ptr * const  at_cZeros;
extern const unary_function_ptr * const  at_cache_tortue;
extern const unary_function_ptr * const  at_calc_mode;
extern const unary_function_ptr * const  at_camembert;
extern const unary_function_ptr * const  at_canonical_form;
extern const unary_function_ptr * const  at_canonical_labeling;
extern const unary_function_ptr * const  at_cap;
extern const unary_function_ptr * const  at_cartesian_product;
extern const unary_function_ptr * const  at_cas_setup;
extern const unary_function_ptr * const  at_caseval;
extern const unary_function_ptr * const  at_cat;
extern const unary_function_ptr * const  at_cauchy;
extern const unary_function_ptr * const  at_cauchy_cdf;
extern const unary_function_ptr * const  at_cauchy_icdf;
extern const unary_function_ptr * const  at_cauchyd;
extern const unary_function_ptr * const  at_cauchyd_cdf;
extern const unary_function_ptr * const  at_cauchyd_icdf;
extern const unary_function_ptr * const  at_cd;
extern const unary_function_ptr * const  at_cdf;
extern const unary_function_ptr * const  at_cdfplot;
extern const unary_function_ptr * const  at_ceil;
extern const unary_function_ptr * const  at_ceiling;
extern const unary_function_ptr * const  at_cell;
extern const unary_function_ptr * const  at_center;
extern const unary_function_ptr * const  at_center2interval;
extern const unary_function_ptr * const  at_centered_cube;
extern const unary_function_ptr * const  at_centered_tetrahedron;
extern const unary_function_ptr * const  at_cfactor;
extern const unary_function_ptr * const  at_cfsolve;
extern const unary_function_ptr * const  at_changebase;
extern const unary_function_ptr * const  at_channel_data;
extern const unary_function_ptr * const  at_channels;
extern const unary_function_ptr * const  at_char;
extern const unary_function_ptr * const  at_charpoly;
extern const unary_function_ptr * const  at_chinrem;
extern const unary_function_ptr * const  at_chisquare;
extern const unary_function_ptr * const  at_chisquare_cdf;
extern const unary_function_ptr * const  at_chisquare_icdf;
extern const unary_function_ptr * const  at_chisquared;
extern const unary_function_ptr * const  at_chisquared_cdf;
extern const unary_function_ptr * const  at_chisquared_icdf;
extern const unary_function_ptr * const  at_chisquaret;
extern const unary_function_ptr * const  at_choice;
extern const unary_function_ptr * const  at_cholesky;
extern const unary_function_ptr * const  at_choosebox;
extern const unary_function_ptr * const  at_chr;
extern const unary_function_ptr * const  at_chrem;
extern const unary_function_ptr * const  at_chromatic_index;
extern const unary_function_ptr * const  at_chromatic_number;
extern const unary_function_ptr * const  at_chromatic_polynomial;
extern const unary_function_ptr * const  at_circle;
extern const unary_function_ptr * const  at_circumcircle;
extern const unary_function_ptr * const  at_classes;
extern const unary_function_ptr * const  at_clear;
extern const unary_function_ptr * const  at_clearscreen;
extern const unary_function_ptr * const  at_click;
extern const unary_function_ptr * const  at_clique_cover;
extern const unary_function_ptr * const  at_clique_cover_number;
extern const unary_function_ptr * const  at_clique_number;
extern const unary_function_ptr * const  at_clique_stats;
extern const unary_function_ptr * const  at_close;
extern const unary_function_ptr * const  at_clustering_coefficient;
extern const unary_function_ptr * const  at_coeff;
extern const unary_function_ptr * const  at_coeffs;
extern const unary_function_ptr * const  at_col;
extern const unary_function_ptr * const  at_colDim;
extern const unary_function_ptr * const  at_colNorm;
extern const unary_function_ptr * const  at_colSwap;
extern const unary_function_ptr * const  at_coldim;
extern const unary_function_ptr * const  at_collect;
extern const unary_function_ptr * const  at_colnorm;
extern const unary_function_ptr * const  at_color;
extern const unary_function_ptr * const  at_colspace;
extern const unary_function_ptr * const  at_colswap;
extern const unary_function_ptr * const  at_comDenom;
extern const unary_function_ptr * const  at_comb;
extern const unary_function_ptr * const  at_combine;
extern const unary_function_ptr * const  at_comment;
extern const unary_function_ptr * const  at_common_perpendicular;
extern const unary_function_ptr * const  at_companion;
extern const unary_function_ptr * const  at_compare;
extern const unary_function_ptr * const  at_complete_binary_tree;
extern const unary_function_ptr * const  at_complete_graph;
extern const unary_function_ptr * const  at_complete_kary_tree;
extern const unary_function_ptr * const  at_complex;
extern const unary_function_ptr * const  at_complexroot;
extern const unary_function_ptr * const  at_concat;
extern const unary_function_ptr * const  at_cond;
extern const unary_function_ptr * const  at_condensation;
extern const unary_function_ptr * const  at_cone;
extern const unary_function_ptr * const  at_conic;
extern const unary_function_ptr * const  at_conj;
extern const unary_function_ptr * const  at_conjugate_equation;
extern const unary_function_ptr * const  at_conjugate_gradient;
extern const unary_function_ptr * const  at_connected_components;
extern const unary_function_ptr * const  at_cont;
extern const unary_function_ptr * const  at_contains;
extern const unary_function_ptr * const  at_content;
extern const unary_function_ptr * const  at_contourplot;
extern const unary_function_ptr * const  at_contract_edge;
extern const unary_function_ptr * const  at_convert;
extern const unary_function_ptr * const  at_convert3d;
extern const unary_function_ptr * const  at_convertir;
extern const unary_function_ptr * const  at_convex;
extern const unary_function_ptr * const  at_convexhull;
extern const unary_function_ptr * const  at_convolution;
extern const unary_function_ptr * const  at_coordinates;
extern const unary_function_ptr * const  at_copy;
extern const unary_function_ptr * const  at_copysign;
extern const unary_function_ptr * const  at_correlation;
extern const unary_function_ptr * const  at_cos;
extern const unary_function_ptr * const  at_cos2sintan;
extern const unary_function_ptr * const  at_cosh;
extern const unary_function_ptr * const  at_cosine_window;
extern const unary_function_ptr * const  at_cot;
extern const unary_function_ptr * const  at_cote;
extern const unary_function_ptr * const  at_coth;
extern const unary_function_ptr * const  at_count;
extern const unary_function_ptr * const  at_count_eq;
extern const unary_function_ptr * const  at_count_inf;
extern const unary_function_ptr * const  at_count_sup;
extern const unary_function_ptr * const  at_courbe_parametrique;
extern const unary_function_ptr * const  at_courbe_polaire;
extern const unary_function_ptr * const  at_covariance;
extern const unary_function_ptr * const  at_covariance_correlation;
extern const unary_function_ptr * const  at_cpartfrac;
extern const unary_function_ptr * const  at_cpp;
extern const unary_function_ptr * const  at_cprint;
extern const unary_function_ptr * const  at_crationalroot;
extern const unary_function_ptr * const  at_crayon;
extern const unary_function_ptr * const  at_createwav;
extern const unary_function_ptr * const  at_critical;
extern const unary_function_ptr * const  at_cross;
extern const unary_function_ptr * const  at_crossP;
extern const unary_function_ptr * const  at_cross_correlation;
extern const unary_function_ptr * const  at_cross_ratio;
extern const unary_function_ptr * const  at_crossproduct;
extern const unary_function_ptr * const  at_csc;
extern const unary_function_ptr * const  at_csch;
extern const unary_function_ptr * const  at_csolve;
extern const unary_function_ptr * const  at_csv2gen;
extern const unary_function_ptr * const  at_cube;
extern const unary_function_ptr * const  at_cumSum;
extern const unary_function_ptr * const  at_cumsum;
extern const unary_function_ptr * const  at_cumulated_frequencies;
extern const unary_function_ptr * const  at_curl;
extern const unary_function_ptr * const  at_current_sheet;
extern const unary_function_ptr * const  at_curvature;
extern const unary_function_ptr * const  at_curve;
extern const unary_function_ptr * const  at_cyan;
extern const unary_function_ptr * const  at_cycle2perm;
extern const unary_function_ptr * const  at_cycle_basis;
extern const unary_function_ptr * const  at_cycle_graph;
extern const unary_function_ptr * const  at_cycleinv;
extern const unary_function_ptr * const  at_cycles2permu;
extern const unary_function_ptr * const  at_cyclotomic;
extern const unary_function_ptr * const  at_cylinder;
extern const unary_function_ptr * const  at_czeros;
extern const unary_function_ptr * const  at_dayofweek;
extern const unary_function_ptr * const  at_de;
extern const unary_function_ptr * const  at_deSolve;
extern const unary_function_ptr * const  at_debug;
extern const unary_function_ptr * const  at_debug_infolevel;
extern const unary_function_ptr * const  at_debut_enregistrement;
extern const unary_function_ptr * const  at_decrement;
extern const unary_function_ptr * const  at_degree;
extern const unary_function_ptr * const  at_degree_sequence;
extern const unary_function_ptr * const  at_del;
extern const unary_function_ptr * const  at_delcols;
extern const unary_function_ptr * const  at_delete_arc;
extern const unary_function_ptr * const  at_delete_edge;
extern const unary_function_ptr * const  at_delete_vertex;
extern const unary_function_ptr * const  at_delrows;
extern const unary_function_ptr * const  at_deltalist;
extern const unary_function_ptr * const  at_denom;
extern const unary_function_ptr * const  at_densityplot;
extern const unary_function_ptr * const  at_departures;
extern const unary_function_ptr * const  at_deriver;
extern const unary_function_ptr * const  at_desolve;
extern const unary_function_ptr * const  at_dessine_tortue;
extern const unary_function_ptr * const  at_det;
extern const unary_function_ptr * const  at_det_minor;
extern const unary_function_ptr * const  at_developper;
extern const unary_function_ptr * const  at_developper_transcendant;
extern const unary_function_ptr * const  at_dfc;
extern const unary_function_ptr * const  at_dfc2f;
extern const unary_function_ptr * const  at_diag;
extern const unary_function_ptr * const  at_diff;
extern const unary_function_ptr * const  at_digraph;
extern const unary_function_ptr * const  at_dijkstra;
extern const unary_function_ptr * const  at_dim;
extern const unary_function_ptr * const  at_discard_edge_attribute;
extern const unary_function_ptr * const  at_discard_graph_attribute;
extern const unary_function_ptr * const  at_discard_vertex_attribute;
extern const unary_function_ptr * const  at_discreted;
extern const unary_function_ptr * const  at_disjoint_union;
extern const unary_function_ptr * const  at_display;
extern const unary_function_ptr * const  at_disque;
extern const unary_function_ptr * const  at_disque_centre;
extern const unary_function_ptr * const  at_distance;
extern const unary_function_ptr * const  at_distance2;
extern const unary_function_ptr * const  at_distanceat;
extern const unary_function_ptr * const  at_distanceatraw;
extern const unary_function_ptr * const  at_div;
extern const unary_function_ptr * const  at_divcrement;
extern const unary_function_ptr * const  at_divergence;
extern const unary_function_ptr * const  at_divide;
extern const unary_function_ptr * const  at_divis;
extern const unary_function_ptr * const  at_division_point;
extern const unary_function_ptr * const  at_divisors;
extern const unary_function_ptr * const  at_divmod;
extern const unary_function_ptr * const  at_divpc;
extern const unary_function_ptr * const  at_dodecahedron;
extern const unary_function_ptr * const  at_domain;
extern const unary_function_ptr * const  at_dot;
extern const unary_function_ptr * const  at_dotP;
extern const unary_function_ptr * const  at_dot_paper;
extern const unary_function_ptr * const  at_dotprod;
extern const unary_function_ptr * const  at_draw_arc;
extern const unary_function_ptr * const  at_draw_circle;
extern const unary_function_ptr * const  at_draw_graph;
extern const unary_function_ptr * const  at_draw_line;
extern const unary_function_ptr * const  at_draw_pixel;
extern const unary_function_ptr * const  at_draw_polygon;
extern const unary_function_ptr * const  at_draw_rectangle;
extern const unary_function_ptr * const  at_draw_string;
extern const unary_function_ptr * const  at_droit;
extern const unary_function_ptr * const  at_droite_tangente;
extern const unary_function_ptr * const  at_dsolve;
extern const unary_function_ptr * const  at_dtype;
extern const unary_function_ptr * const  at_duration;
extern const unary_function_ptr * const  at_e2r;
extern const unary_function_ptr * const  at_ecart_type;
extern const unary_function_ptr * const  at_ecart_type_population;
extern const unary_function_ptr * const  at_ecm_factor;
extern const unary_function_ptr * const  at_ecris;
extern const unary_function_ptr * const  at_edge_connectivity;
extern const unary_function_ptr * const  at_edges;
extern const unary_function_ptr * const  at_efface;
extern const unary_function_ptr * const  at_egcd;
extern const unary_function_ptr * const  at_egv;
extern const unary_function_ptr * const  at_egvl;
extern const unary_function_ptr * const  at_eigVc;
extern const unary_function_ptr * const  at_eigVl;
extern const unary_function_ptr * const  at_eigenvals;
extern const unary_function_ptr * const  at_eigenvalues;
extern const unary_function_ptr * const  at_eigenvectors;
extern const unary_function_ptr * const  at_eigenvects;
extern const unary_function_ptr * const  at_element;
extern const unary_function_ptr * const  at_eliminate;
extern const unary_function_ptr * const  at_ellipse;
extern const unary_function_ptr * const  at_entry;
extern const unary_function_ptr * const  at_envelope;
extern const unary_function_ptr * const  at_epsilon2zero;
extern const unary_function_ptr * const  at_equal2diff;
extern const unary_function_ptr * const  at_equal2list;
extern const unary_function_ptr * const  at_equation;
extern const unary_function_ptr * const  at_equilateral_triangle;
extern const unary_function_ptr * const  at_erase3d;
extern const unary_function_ptr * const  at_erf;
extern const unary_function_ptr * const  at_erfc;
extern const unary_function_ptr * const  at_erfs;
extern const unary_function_ptr * const  at_et;
extern const unary_function_ptr * const  at_euler;
extern const unary_function_ptr * const  at_euler_lagrange;
extern const unary_function_ptr * const  at_euler_mac_laurin;
extern const unary_function_ptr * const  at_eval;
extern const unary_function_ptr * const  at_eval_level;
extern const unary_function_ptr * const  at_evala;
extern const unary_function_ptr * const  at_evalb;
extern const unary_function_ptr * const  at_evalc;
extern const unary_function_ptr * const  at_evalf;
extern const unary_function_ptr * const  at_evalfa;
extern const unary_function_ptr * const  at_evalm;
extern const unary_function_ptr * const  at_even;
extern const unary_function_ptr * const  at_evolute;
extern const unary_function_ptr * const  at_exact;
extern const unary_function_ptr * const  at_exbisector;
extern const unary_function_ptr * const  at_excircle;
extern const unary_function_ptr * const  at_execute;
extern const unary_function_ptr * const  at_exp;
extern const unary_function_ptr * const  at_exp2list;
extern const unary_function_ptr * const  at_exp2pow;
extern const unary_function_ptr * const  at_exp2trig;
extern const unary_function_ptr * const  at_expexpand;
extern const unary_function_ptr * const  at_expln2trig;
extern const unary_function_ptr * const  at_expm1;
extern const unary_function_ptr * const  at_exponential;
extern const unary_function_ptr * const  at_exponential_cdf;
extern const unary_function_ptr * const  at_exponential_icdf;
extern const unary_function_ptr * const  at_exponential_regression;
extern const unary_function_ptr * const  at_exponential_regression_plot;
extern const unary_function_ptr * const  at_exponentiald;
extern const unary_function_ptr * const  at_exponentiald_cdf;
extern const unary_function_ptr * const  at_exponentiald_icdf;
extern const unary_function_ptr * const  at_export_graph;
extern const unary_function_ptr * const  at_expovariate;
extern const unary_function_ptr * const  at_expr;
extern const unary_function_ptr * const  at_extend;
extern const unary_function_ptr * const  at_extract_measure;
extern const unary_function_ptr * const  at_extrema;
extern const unary_function_ptr * const  at_ezgcd;
extern const unary_function_ptr * const  at_f2nd;
extern const unary_function_ptr * const  at_fMax;
extern const unary_function_ptr * const  at_fMin;
extern const unary_function_ptr * const  at_fPart;
extern const unary_function_ptr * const  at_faces;
extern const unary_function_ptr * const  at_facteurs_premiers;
extern const unary_function_ptr * const  at_factor;
extern const unary_function_ptr * const  at_factor_xn;
extern const unary_function_ptr * const  at_factorial;
extern const unary_function_ptr * const  at_factoriser;
extern const unary_function_ptr * const  at_factoriser_entier;
extern const unary_function_ptr * const  at_factoriser_sur_C;
extern const unary_function_ptr * const  at_factoriser_xn;
extern const unary_function_ptr * const  at_factors;
extern const unary_function_ptr * const  at_faire;
extern const unary_function_ptr * const  at_fclose;
extern const unary_function_ptr * const  at_fcoeff;
extern const unary_function_ptr * const  at_fft;
extern const unary_function_ptr * const  at_fft_mult_size;
extern const unary_function_ptr * const  at_fieldplot;
extern const unary_function_ptr * const  at_fill_rect;
extern const unary_function_ptr * const  at_filled;
extern const unary_function_ptr * const  at_filter;
extern const unary_function_ptr * const  at_fin_enregistrement;
extern const unary_function_ptr * const  at_find;
extern const unary_function_ptr * const  at_find_cycles;
extern const unary_function_ptr * const  at_findhelp;
extern const unary_function_ptr * const  at_fisher;
extern const unary_function_ptr * const  at_fisher_cdf;
extern const unary_function_ptr * const  at_fisher_icdf;
extern const unary_function_ptr * const  at_fisherd;
extern const unary_function_ptr * const  at_fisherd_cdf;
extern const unary_function_ptr * const  at_fisherd_icdf;
extern const unary_function_ptr * const  at_fitdistr;
extern const unary_function_ptr * const  at_flatten;
extern const unary_function_ptr * const  at_flatten1;
extern const unary_function_ptr * const  at_float;
extern const unary_function_ptr * const  at_float2rational;
extern const unary_function_ptr * const  at_floor;
extern const unary_function_ptr * const  at_flow_polynomial;
extern const unary_function_ptr * const  at_fmod;
extern const unary_function_ptr * const  at_foldl;
extern const unary_function_ptr * const  at_foldr;
extern const unary_function_ptr * const  at_fonction;
extern const unary_function_ptr * const  at_fonction_derivee;
extern const unary_function_ptr * const  at_fopen;
extern const unary_function_ptr * const  at_format;
extern const unary_function_ptr * const  at_forward;
extern const unary_function_ptr * const  at_fourier_an;
extern const unary_function_ptr * const  at_fourier_bn;
extern const unary_function_ptr * const  at_fourier_cn;
extern const unary_function_ptr * const  at_fprint;
extern const unary_function_ptr * const  at_frac;
extern const unary_function_ptr * const  at_fracmod;
extern const unary_function_ptr * const  at_frame_2d;
extern const unary_function_ptr * const  at_frame_3d;
extern const unary_function_ptr * const  at_frenet;
extern const unary_function_ptr * const  at_frequencies;
extern const unary_function_ptr * const  at_frexp;
extern const unary_function_ptr * const  at_frobenius_norm;
extern const unary_function_ptr * const  at_froot;
extern const unary_function_ptr * const  at_fsolve;
extern const unary_function_ptr * const  at_funcplot;
extern const unary_function_ptr * const  at_function_diff;
extern const unary_function_ptr * const  at_fundamental_cycle;
extern const unary_function_ptr * const  at_fxnd;
extern const unary_function_ptr * const  at_galoisconj;
extern const unary_function_ptr * const  at_gammad;
extern const unary_function_ptr * const  at_gammad_cdf;
extern const unary_function_ptr * const  at_gammad_icdf;
extern const unary_function_ptr * const  at_gammavariate;
extern const unary_function_ptr * const  at_gauche;
extern const unary_function_ptr * const  at_gauss;
extern const unary_function_ptr * const  at_gauss_seidel_linsolve;
extern const unary_function_ptr * const  at_gaussian_window;
extern const unary_function_ptr * const  at_gaussjord;
extern const unary_function_ptr * const  at_gaussquad;
extern const unary_function_ptr * const  at_gbasis;
extern const unary_function_ptr * const  at_gbasis_max_pairs;
extern const unary_function_ptr * const  at_gbasis_reinject;
extern const unary_function_ptr * const  at_gbasis_simult_primes;
extern const unary_function_ptr * const  at_gcd;
extern const unary_function_ptr * const  at_gcdex;
extern const unary_function_ptr * const  at_genpoly;
extern const unary_function_ptr * const  at_geo2d;
extern const unary_function_ptr * const  at_geo3d;
extern const unary_function_ptr * const  at_geometric;
extern const unary_function_ptr * const  at_geometric_cdf;
extern const unary_function_ptr * const  at_geometric_icdf;
extern const unary_function_ptr * const  at_getDenom;
extern const unary_function_ptr * const  at_getKey;
extern const unary_function_ptr * const  at_getNum;
extern const unary_function_ptr * const  at_getType;
extern const unary_function_ptr * const  at_get_edge_attribute;
extern const unary_function_ptr * const  at_get_edge_weight;
extern const unary_function_ptr * const  at_get_graph_attribute;
extern const unary_function_ptr * const  at_get_pixel;
extern const unary_function_ptr * const  at_get_vertex_attribute;
extern const unary_function_ptr * const  at_ggb_ang;
extern const unary_function_ptr * const  at_ggbalt;
extern const unary_function_ptr * const  at_ggbsort;
extern const unary_function_ptr * const  at_giac;
extern const unary_function_ptr * const  at_girth;
extern const unary_function_ptr * const  at_goto;
extern const unary_function_ptr * const  at_grad;
extern const unary_function_ptr * const  at_gramschmidt;
extern const unary_function_ptr * const  at_graph;
extern const unary_function_ptr * const  at_graph2tex;
extern const unary_function_ptr * const  at_graph3d2tex;
extern const unary_function_ptr * const  at_graph_automorphisms;
extern const unary_function_ptr * const  at_graph_charpoly;
extern const unary_function_ptr * const  at_graph_complement;
extern const unary_function_ptr * const  at_graph_diameter;
extern const unary_function_ptr * const  at_graph_equal;
extern const unary_function_ptr * const  at_graph_join;
extern const unary_function_ptr * const  at_graph_power;
extern const unary_function_ptr * const  at_graph_rank;
extern const unary_function_ptr * const  at_graph_scc;
extern const unary_function_ptr * const  at_graph_spectrum;
extern const unary_function_ptr * const  at_graph_union;
extern const unary_function_ptr * const  at_graph_vertices;
extern const unary_function_ptr * const  at_graphe;
extern const unary_function_ptr * const  at_graphe3d;
extern const unary_function_ptr * const  at_graphe_suite;
extern const unary_function_ptr * const  at_greduce;
extern const unary_function_ptr * const  at_greedy_color;
extern const unary_function_ptr * const  at_green;
extern const unary_function_ptr * const  at_grid_graph;
extern const unary_function_ptr * const  at_grid_paper;
extern const unary_function_ptr * const  at_groupermu;
extern const unary_function_ptr * const  at_hadamard;
extern const unary_function_ptr * const  at_half_cone;
extern const unary_function_ptr * const  at_half_line;
extern const unary_function_ptr * const  at_halftan;
extern const unary_function_ptr * const  at_halftan_hyp2exp;
extern const unary_function_ptr * const  at_halt;
extern const unary_function_ptr * const  at_hamdist;
extern const unary_function_ptr * const  at_hamming_window;
extern const unary_function_ptr * const  at_hann_poisson_window;
extern const unary_function_ptr * const  at_hann_window;
extern const unary_function_ptr * const  at_harmonic;
extern const unary_function_ptr * const  at_harmonic_conjugate;
extern const unary_function_ptr * const  at_harmonic_division;
extern const unary_function_ptr * const  at_has;
extern const unary_function_ptr * const  at_has_arc;
extern const unary_function_ptr * const  at_has_edge;
extern const unary_function_ptr * const  at_hasard;
extern const unary_function_ptr * const  at_head;
extern const unary_function_ptr * const  at_heading;
extern const unary_function_ptr * const  at_heap_mult;
extern const unary_function_ptr * const  at_heapify;
extern const unary_function_ptr * const  at_heappop;
extern const unary_function_ptr * const  at_heappush;
extern const unary_function_ptr * const  at_help;
extern const unary_function_ptr * const  at_hermite;
extern const unary_function_ptr * const  at_hessenberg;
extern const unary_function_ptr * const  at_hessian;
extern const unary_function_ptr * const  at_heugcd;
extern const unary_function_ptr * const  at_hex;
extern const unary_function_ptr * const  at_hexagon;
extern const unary_function_ptr * const  at_hexprint;
extern const unary_function_ptr * const  at_hidden_name;
extern const unary_function_ptr * const  at_hideturtle;
extern const unary_function_ptr * const  at_highlight_edges;
extern const unary_function_ptr * const  at_highlight_subgraph;
extern const unary_function_ptr * const  at_highlight_trail;
extern const unary_function_ptr * const  at_highlight_vertex;
extern const unary_function_ptr * const  at_highpass;
extern const unary_function_ptr * const  at_hilbert;
extern const unary_function_ptr * const  at_histogram;
extern const unary_function_ptr * const  at_hold;
extern const unary_function_ptr * const  at_homothety;
extern const unary_function_ptr * const  at_horner;
extern const unary_function_ptr * const  at_hp38;
extern const unary_function_ptr * const  at_hyp2exp;
extern const unary_function_ptr * const  at_hyperbola;
extern const unary_function_ptr * const  at_hypercube_graph;
extern const unary_function_ptr * const  at_hyperplan;
extern const unary_function_ptr * const  at_hypersphere;
extern const unary_function_ptr * const  at_hypersurface;
extern const unary_function_ptr * const  at_iPart;
extern const unary_function_ptr * const  at_iabcuv;
extern const unary_function_ptr * const  at_ibasis;
extern const unary_function_ptr * const  at_ibpdv;
extern const unary_function_ptr * const  at_ibpu;
extern const unary_function_ptr * const  at_icdf;
extern const unary_function_ptr * const  at_ichinrem;
extern const unary_function_ptr * const  at_ichrem;
extern const unary_function_ptr * const  at_icomp;
extern const unary_function_ptr * const  at_icontent;
extern const unary_function_ptr * const  at_icosahedron;
extern const unary_function_ptr * const  at_id;
extern const unary_function_ptr * const  at_identity;
extern const unary_function_ptr * const  at_idivis;
extern const unary_function_ptr * const  at_idn;
extern const unary_function_ptr * const  at_iegcd;
extern const unary_function_ptr * const  at_ifactor;
extern const unary_function_ptr * const  at_ifactors;
extern const unary_function_ptr * const  at_ifft;
extern const unary_function_ptr * const  at_igamma;
extern const unary_function_ptr * const  at_igamma_exp;
extern const unary_function_ptr * const  at_igcd;
extern const unary_function_ptr * const  at_igcdex;
extern const unary_function_ptr * const  at_ihermite;
extern const unary_function_ptr * const  at_ilaplace;
extern const unary_function_ptr * const  at_im;
extern const unary_function_ptr * const  at_imag;
extern const unary_function_ptr * const  at_image;
extern const unary_function_ptr * const  at_implicit_diff;
extern const unary_function_ptr * const  at_implicitdiff;
extern const unary_function_ptr * const  at_implicitplot;
extern const unary_function_ptr * const  at_implicitplot3d;
extern const unary_function_ptr * const  at_import_graph;
extern const unary_function_ptr * const  at_inString;
extern const unary_function_ptr * const  at_in_ideal;
extern const unary_function_ptr * const  at_incidence_matrix;
extern const unary_function_ptr * const  at_incident_edges;
extern const unary_function_ptr * const  at_incircle;
extern const unary_function_ptr * const  at_increment;
extern const unary_function_ptr * const  at_independence_number;
extern const unary_function_ptr * const  at_indets;
extern const unary_function_ptr * const  at_index;
extern const unary_function_ptr * const  at_induced_subgraph;
extern const unary_function_ptr * const  at_inequationplot;
extern const unary_function_ptr * const  at_inferieur_strict_sort;
extern const unary_function_ptr * const  at_innertln;
extern const unary_function_ptr * const  at_input;
extern const unary_function_ptr * const  at_inputform;
extern const unary_function_ptr * const  at_insert;
extern const unary_function_ptr * const  at_insmod;
extern const unary_function_ptr * const  at_int;
extern const unary_function_ptr * const  at_intDiv;
extern const unary_function_ptr * const  at_integer_format;
extern const unary_function_ptr * const  at_integrate;
extern const unary_function_ptr * const  at_integrer;
extern const unary_function_ptr * const  at_inter;
extern const unary_function_ptr * const  at_interactive;
extern const unary_function_ptr * const  at_interactive_odeplot;
extern const unary_function_ptr * const  at_interactive_plotode;
extern const unary_function_ptr * const  at_interp;
extern const unary_function_ptr * const  at_interval2center;
extern const unary_function_ptr * const  at_interval_graph;
extern const unary_function_ptr * const  at_inv;
extern const unary_function_ptr * const  at_invd_blocksize;
extern const unary_function_ptr * const  at_inverse;
extern const unary_function_ptr * const  at_inversion;
extern const unary_function_ptr * const  at_invlaplace;
extern const unary_function_ptr * const  at_invztrans;
extern const unary_function_ptr * const  at_iquo;
extern const unary_function_ptr * const  at_iquorem;
extern const unary_function_ptr * const  at_iquosto;
extern const unary_function_ptr * const  at_iratrecon;
extern const unary_function_ptr * const  at_irem;
extern const unary_function_ptr * const  at_iremsto;
extern const unary_function_ptr * const  at_isPrime;
extern const unary_function_ptr * const  at_is_3dpoint;
extern const unary_function_ptr * const  at_is_acyclic;
extern const unary_function_ptr * const  at_is_arborescence;
extern const unary_function_ptr * const  at_is_biconnected;
extern const unary_function_ptr * const  at_is_bipartite;
extern const unary_function_ptr * const  at_is_clique;
extern const unary_function_ptr * const  at_is_collinear;
extern const unary_function_ptr * const  at_is_concyclic;
extern const unary_function_ptr * const  at_is_conjugate;
extern const unary_function_ptr * const  at_is_connected;
extern const unary_function_ptr * const  at_is_coplanar;
extern const unary_function_ptr * const  at_is_cospherical;
extern const unary_function_ptr * const  at_is_cut_set;
extern const unary_function_ptr * const  at_is_cycle;
extern const unary_function_ptr * const  at_is_directed;
extern const unary_function_ptr * const  at_is_element;
extern const unary_function_ptr * const  at_is_equilateral;
extern const unary_function_ptr * const  at_is_eulerian;
extern const unary_function_ptr * const  at_is_forest;
extern const unary_function_ptr * const  at_is_graphic_sequence;
extern const unary_function_ptr * const  at_is_hamiltonian;
extern const unary_function_ptr * const  at_is_harmonic;
extern const unary_function_ptr * const  at_is_harmonic_circle_bundle;
extern const unary_function_ptr * const  at_is_harmonic_line_bundle;
extern const unary_function_ptr * const  at_is_included;
extern const unary_function_ptr * const  at_is_inside;
extern const unary_function_ptr * const  at_is_integer_graph;
extern const unary_function_ptr * const  at_is_isomorphic;
extern const unary_function_ptr * const  at_is_isosceles;
extern const unary_function_ptr * const  at_is_matrix;
extern const unary_function_ptr * const  at_is_network;
extern const unary_function_ptr * const  at_is_orthogonal;
extern const unary_function_ptr * const  at_is_parallel;
extern const unary_function_ptr * const  at_is_parallelogram;
extern const unary_function_ptr * const  at_is_permu;
extern const unary_function_ptr * const  at_is_perpendicular;
extern const unary_function_ptr * const  at_is_planar;
extern const unary_function_ptr * const  at_is_polynomial;
extern const unary_function_ptr * const  at_is_prime;
extern const unary_function_ptr * const  at_is_pseudoprime;
extern const unary_function_ptr * const  at_is_rectangle;
extern const unary_function_ptr * const  at_is_regular;
extern const unary_function_ptr * const  at_is_rhombus;
extern const unary_function_ptr * const  at_is_square;
extern const unary_function_ptr * const  at_is_strongly_connected;
extern const unary_function_ptr * const  at_is_strongly_regular;
extern const unary_function_ptr * const  at_is_tournament;
extern const unary_function_ptr * const  at_is_tree;
extern const unary_function_ptr * const  at_is_triconnected;
extern const unary_function_ptr * const  at_is_two_edge_connected;
extern const unary_function_ptr * const  at_is_vertex_colorable;
extern const unary_function_ptr * const  at_is_weighted;
extern const unary_function_ptr * const  at_isfinite;
extern const unary_function_ptr * const  at_isinf;
extern const unary_function_ptr * const  at_ismith;
extern const unary_function_ptr * const  at_isnan;
extern const unary_function_ptr * const  at_isobarycenter;
extern const unary_function_ptr * const  at_isom;
extern const unary_function_ptr * const  at_isomorphic_copy;
extern const unary_function_ptr * const  at_isopolygon;
extern const unary_function_ptr * const  at_isosceles_triangle;
extern const unary_function_ptr * const  at_isprime;
extern const unary_function_ptr * const  at_ithprime;
extern const unary_function_ptr * const  at_jacobi_equation;
extern const unary_function_ptr * const  at_jacobi_linsolve;
extern const unary_function_ptr * const  at_jacobi_symbol;
extern const unary_function_ptr * const  at_javascript;
extern const unary_function_ptr * const  at_join;
extern const unary_function_ptr * const  at_jordan;
extern const unary_function_ptr * const  at_jump;
extern const unary_function_ptr * const  at_jusque;
extern const unary_function_ptr * const  at_kde;
extern const unary_function_ptr * const  at_ker;
extern const unary_function_ptr * const  at_kernel;
extern const unary_function_ptr * const  at_kernel_density;
extern const unary_function_ptr * const  at_keyboard;
extern const unary_function_ptr * const  at_kill;
extern const unary_function_ptr * const  at_kneser_graph;
extern const unary_function_ptr * const  at_kolmogorovd;
extern const unary_function_ptr * const  at_kolmogorovt;
extern const unary_function_ptr * const  at_kovacicsols;
extern const unary_function_ptr * const  at_kspaths;
extern const unary_function_ptr * const  at_l1norm;
extern const unary_function_ptr * const  at_l2norm;
extern const unary_function_ptr * const  at_label;
extern const unary_function_ptr * const  at_lagrange;
extern const unary_function_ptr * const  at_laguerre;
extern const unary_function_ptr * const  at_lapack_limit;
extern const unary_function_ptr * const  at_laplace;
extern const unary_function_ptr * const  at_laplacian;
extern const unary_function_ptr * const  at_laplacian_matrix;
extern const unary_function_ptr * const  at_latex;
extern const unary_function_ptr * const  at_lcf_graph;
extern const unary_function_ptr * const  at_lcm;
extern const unary_function_ptr * const  at_lcoeff;
extern const unary_function_ptr * const  at_ldegree;
extern const unary_function_ptr * const  at_ldexp;
extern const unary_function_ptr * const  at_left;
extern const unary_function_ptr * const  at_legend;
extern const unary_function_ptr * const  at_legendre;
extern const unary_function_ptr * const  at_legendre_symbol;
extern const unary_function_ptr * const  at_len;
extern const unary_function_ptr * const  at_length;
extern const unary_function_ptr * const  at_leve_crayon;
extern const unary_function_ptr * const  at_lgamma;
extern const unary_function_ptr * const  at_lgcd;
extern const unary_function_ptr * const  at_lhs;
extern const unary_function_ptr * const  at_ligne_polygonale;
extern const unary_function_ptr * const  at_ligne_polygonale_pointee;
extern const unary_function_ptr * const  at_limit;
extern const unary_function_ptr * const  at_limite;
extern const unary_function_ptr * const  at_lin;
extern const unary_function_ptr * const  at_line;
extern const unary_function_ptr * const  at_line_graph;
extern const unary_function_ptr * const  at_line_inter;
extern const unary_function_ptr * const  at_line_paper;
extern const unary_function_ptr * const  at_line_segments;
extern const unary_function_ptr * const  at_linear_interpolate;
extern const unary_function_ptr * const  at_linear_regression;
extern const unary_function_ptr * const  at_linear_regression_plot;
extern const unary_function_ptr * const  at_lineariser;
extern const unary_function_ptr * const  at_lineariser_trigo;
extern const unary_function_ptr * const  at_linfnorm;
extern const unary_function_ptr * const  at_link2giac;
extern const unary_function_ptr * const  at_linsolve;
extern const unary_function_ptr * const  at_linspace;
extern const unary_function_ptr * const  at_lis;
extern const unary_function_ptr * const  at_lis_phrase;
extern const unary_function_ptr * const  at_list2exp;
extern const unary_function_ptr * const  at_list2mat;
extern const unary_function_ptr * const  at_list_edge_attributes;
extern const unary_function_ptr * const  at_list_graph_attributes;
extern const unary_function_ptr * const  at_list_vertex_attributes;
extern const unary_function_ptr * const  at_listplot;
extern const unary_function_ptr * const  at_lll;
extern const unary_function_ptr * const  at_lll_reduce;
extern const unary_function_ptr * const  at_ln;
extern const unary_function_ptr * const  at_lnGamma_minus;
extern const unary_function_ptr * const  at_lname;
extern const unary_function_ptr * const  at_lncollect;
extern const unary_function_ptr * const  at_lnexpand;
extern const unary_function_ptr * const  at_locus;
extern const unary_function_ptr * const  at_log10;
extern const unary_function_ptr * const  at_log1p;
extern const unary_function_ptr * const  at_logarithmic_regression;
extern const unary_function_ptr * const  at_logarithmic_regression_plot;
extern const unary_function_ptr * const  at_logb;
extern const unary_function_ptr * const  at_logistic_regression;
extern const unary_function_ptr * const  at_logistic_regression_plot;
extern const unary_function_ptr * const  at_lower;
extern const unary_function_ptr * const  at_lowest_common_ancestor;
extern const unary_function_ptr * const  at_lowpass;
extern const unary_function_ptr * const  at_lpsolve;
extern const unary_function_ptr * const  at_lsmod;
extern const unary_function_ptr * const  at_lsq;
extern const unary_function_ptr * const  at_lu;
extern const unary_function_ptr * const  at_lvar;
extern const unary_function_ptr * const  at_mRow;
extern const unary_function_ptr * const  at_mRowAdd;
extern const unary_function_ptr * const  at_magenta;
extern const unary_function_ptr * const  at_make_directed;
extern const unary_function_ptr * const  at_make_weighted;
extern const unary_function_ptr * const  at_makelist;
extern const unary_function_ptr * const  at_makemat;
extern const unary_function_ptr * const  at_makemod;
extern const unary_function_ptr * const  at_makesuite;
extern const unary_function_ptr * const  at_makevector;
extern const unary_function_ptr * const  at_mantissa;
extern const unary_function_ptr * const  at_map;
extern const unary_function_ptr * const  at_maple2mupad;
extern const unary_function_ptr * const  at_maple2xcas;
extern const unary_function_ptr * const  at_maple_ifactors;
extern const unary_function_ptr * const  at_maple_mode;
extern const unary_function_ptr * const  at_markov;
extern const unary_function_ptr * const  at_mat2list;
extern const unary_function_ptr * const  at_mathml;
extern const unary_function_ptr * const  at_matpow;
extern const unary_function_ptr * const  at_matrix;
extern const unary_function_ptr * const  at_matrix_norm;
extern const unary_function_ptr * const  at_max;
extern const unary_function_ptr * const  at_max_algext;
extern const unary_function_ptr * const  at_maxflow;
extern const unary_function_ptr * const  at_maximize;
extern const unary_function_ptr * const  at_maximum_clique;
extern const unary_function_ptr * const  at_maximum_degree;
extern const unary_function_ptr * const  at_maximum_independent_set;
extern const unary_function_ptr * const  at_maximum_matching;
extern const unary_function_ptr * const  at_maxnorm;
extern const unary_function_ptr * const  at_mean;
extern const unary_function_ptr * const  at_median;
extern const unary_function_ptr * const  at_median_line;
extern const unary_function_ptr * const  at_member;
extern const unary_function_ptr * const  at_mgf;
extern const unary_function_ptr * const  at_mid;
extern const unary_function_ptr * const  at_midpoint;
extern const unary_function_ptr * const  at_min;
extern const unary_function_ptr * const  at_min_proba_time;
extern const unary_function_ptr * const  at_minimal_edge_coloring;
extern const unary_function_ptr * const  at_minimal_spanning_tree;
extern const unary_function_ptr * const  at_minimal_vertex_coloring;
extern const unary_function_ptr * const  at_minimax;
extern const unary_function_ptr * const  at_minimize;
extern const unary_function_ptr * const  at_minimum_cut;
extern const unary_function_ptr * const  at_minimum_degree;
extern const unary_function_ptr * const  at_mkisom;
extern const unary_function_ptr * const  at_mksa;
extern const unary_function_ptr * const  at_modgcd;
extern const unary_function_ptr * const  at_modgcd_cachesize;
extern const unary_function_ptr * const  at_modp;
extern const unary_function_ptr * const  at_mods;
extern const unary_function_ptr * const  at_monotonic;
extern const unary_function_ptr * const  at_montre_tortue;
extern const unary_function_ptr * const  at_moustache;
extern const unary_function_ptr * const  at_moving_average;
extern const unary_function_ptr * const  at_moyal;
extern const unary_function_ptr * const  at_moyenne;
extern const unary_function_ptr * const  at_mpzclass_allowed;
extern const unary_function_ptr * const  at_mul;
extern const unary_function_ptr * const  at_mult_c_conjugate;
extern const unary_function_ptr * const  at_mult_conjugate;
extern const unary_function_ptr * const  at_multcrement;
extern const unary_function_ptr * const  at_multinomial;
extern const unary_function_ptr * const  at_multiplier_conjugue;
extern const unary_function_ptr * const  at_multiplier_conjugue_complexe;
extern const unary_function_ptr * const  at_multiply;
extern const unary_function_ptr * const  at_mupad2maple;
extern const unary_function_ptr * const  at_mupad2xcas;
extern const unary_function_ptr * const  at_mycielski;
extern const unary_function_ptr * const  at_nCr;
extern const unary_function_ptr * const  at_nDeriv;
extern const unary_function_ptr * const  at_nInt;
extern const unary_function_ptr * const  at_nPr;
extern const unary_function_ptr * const  at_nSolve;
extern const unary_function_ptr * const  at_ncols;
extern const unary_function_ptr * const  at_negbinomial;
extern const unary_function_ptr * const  at_negbinomial_cdf;
extern const unary_function_ptr * const  at_negbinomial_icdf;
extern const unary_function_ptr * const  at_neighbors;
extern const unary_function_ptr * const  at_network_transitivity;
extern const unary_function_ptr * const  at_newList;
extern const unary_function_ptr * const  at_newMat;
extern const unary_function_ptr * const  at_newton;
extern const unary_function_ptr * const  at_nextperm;
extern const unary_function_ptr * const  at_nextprime;
extern const unary_function_ptr * const  at_nlpsolve;
extern const unary_function_ptr * const  at_nodisp;
extern const unary_function_ptr * const  at_non;
extern const unary_function_ptr * const  at_non_recursive_normal;
extern const unary_function_ptr * const  at_nop;
extern const unary_function_ptr * const  at_nops;
extern const unary_function_ptr * const  at_norm;
extern const unary_function_ptr * const  at_normal;
extern const unary_function_ptr * const  at_normal_cdf;
extern const unary_function_ptr * const  at_normal_icdf;
extern const unary_function_ptr * const  at_normald;
extern const unary_function_ptr * const  at_normald_cdf;
extern const unary_function_ptr * const  at_normald_icdf;
extern const unary_function_ptr * const  at_normalize;
extern const unary_function_ptr * const  at_normalt;
extern const unary_function_ptr * const  at_normalvariate;
extern const unary_function_ptr * const  at_nprimes;
extern const unary_function_ptr * const  at_nrows;
extern const unary_function_ptr * const  at_nuage_points;
extern const unary_function_ptr * const  at_nullspace;
extern const unary_function_ptr * const  at_number_of_edges;
extern const unary_function_ptr * const  at_number_of_spanning_trees;
extern const unary_function_ptr * const  at_number_of_triangles;
extern const unary_function_ptr * const  at_number_of_vertices;
extern const unary_function_ptr * const  at_numer;
extern const unary_function_ptr * const  at_octahedron;
extern const unary_function_ptr * const  at_octprint;
extern const unary_function_ptr * const  at_odd;
extern const unary_function_ptr * const  at_odd_girth;
extern const unary_function_ptr * const  at_odd_graph;
extern const unary_function_ptr * const  at_odeplot;
extern const unary_function_ptr * const  at_odesolve;
extern const unary_function_ptr * const  at_op;
extern const unary_function_ptr * const  at_open;
extern const unary_function_ptr * const  at_open_polygon;
extern const unary_function_ptr * const  at_or;
extern const unary_function_ptr * const  at_ord;
extern const unary_function_ptr * const  at_order;
extern const unary_function_ptr * const  at_order_size;
extern const unary_function_ptr * const  at_ordinate;
extern const unary_function_ptr * const  at_orsto;
extern const unary_function_ptr * const  at_orthocenter;
extern const unary_function_ptr * const  at_orthogonal;
extern const unary_function_ptr * const  at_os_version;
extern const unary_function_ptr * const  at_osculating_circle;
extern const unary_function_ptr * const  at_ou;
extern const unary_function_ptr * const  at_output;
extern const unary_function_ptr * const  at_p1oc2;
extern const unary_function_ptr * const  at_p1op2;
extern const unary_function_ptr * const  at_pa2b2;
extern const unary_function_ptr * const  at_pade;
extern const unary_function_ptr * const  at_padic_linsolve;
extern const unary_function_ptr * const  at_parabola;
extern const unary_function_ptr * const  at_parabolic_interpolate;
extern const unary_function_ptr * const  at_parallel;
extern const unary_function_ptr * const  at_parallelepiped;
extern const unary_function_ptr * const  at_parallelogram;
extern const unary_function_ptr * const  at_parameq;
extern const unary_function_ptr * const  at_parameter;
extern const unary_function_ptr * const  at_paramplot;
extern const unary_function_ptr * const  at_pari;
extern const unary_function_ptr * const  at_pari_unlock;
extern const unary_function_ptr * const  at_part;
extern const unary_function_ptr * const  at_partfrac;
extern const unary_function_ptr * const  at_parzen_window;
extern const unary_function_ptr * const  at_pas;
extern const unary_function_ptr * const  at_pas_de_cote;
extern const unary_function_ptr * const  at_path_graph;
extern const unary_function_ptr * const  at_pcar;
extern const unary_function_ptr * const  at_pcar_hessenberg;
extern const unary_function_ptr * const  at_pcoeff;
extern const unary_function_ptr * const  at_pencolor;
extern const unary_function_ptr * const  at_pendown;
extern const unary_function_ptr * const  at_penup;
extern const unary_function_ptr * const  at_perimeter;
extern const unary_function_ptr * const  at_perimeterat;
extern const unary_function_ptr * const  at_perimeteratraw;
extern const unary_function_ptr * const  at_periodic;
extern const unary_function_ptr * const  at_perm;
extern const unary_function_ptr * const  at_perminv;
extern const unary_function_ptr * const  at_permu2cycles;
extern const unary_function_ptr * const  at_permu2mat;
extern const unary_function_ptr * const  at_permuorder;
extern const unary_function_ptr * const  at_permute_vertices;
extern const unary_function_ptr * const  at_perpen_bisector;
extern const unary_function_ptr * const  at_perpendicular;
extern const unary_function_ptr * const  at_petersen_graph;
extern const unary_function_ptr * const  at_peval;
extern const unary_function_ptr * const  at_piecewise;
extern const unary_function_ptr * const  at_pivot;
extern const unary_function_ptr * const  at_pixoff;
extern const unary_function_ptr * const  at_pixon;
extern const unary_function_ptr * const  at_plane;
extern const unary_function_ptr * const  at_plane_dual;
extern const unary_function_ptr * const  at_playsnd;
extern const unary_function_ptr * const  at_plot;
extern const unary_function_ptr * const  at_plot3d;
extern const unary_function_ptr * const  at_plot_style;
extern const unary_function_ptr * const  at_plotarea;
extern const unary_function_ptr * const  at_plotcdf;
extern const unary_function_ptr * const  at_plotcontour;
extern const unary_function_ptr * const  at_plotdensity;
extern const unary_function_ptr * const  at_plotfield;
extern const unary_function_ptr * const  at_plotfunc;
extern const unary_function_ptr * const  at_plotimplicit;
extern const unary_function_ptr * const  at_plotinequation;
extern const unary_function_ptr * const  at_plotlist;
extern const unary_function_ptr * const  at_plotmatrix;
extern const unary_function_ptr * const  at_plotode;
extern const unary_function_ptr * const  at_plotparam;
extern const unary_function_ptr * const  at_plotpolar;
extern const unary_function_ptr * const  at_plotproba;
extern const unary_function_ptr * const  at_plotseq;
extern const unary_function_ptr * const  at_plotspectrum;
extern const unary_function_ptr * const  at_plotwav;
extern const unary_function_ptr * const  at_pmin;
extern const unary_function_ptr * const  at_pnt;
extern const unary_function_ptr * const  at_point;
extern const unary_function_ptr * const  at_point2d;
extern const unary_function_ptr * const  at_point3d;
extern const unary_function_ptr * const  at_pointer;
extern const unary_function_ptr * const  at_poisson;
extern const unary_function_ptr * const  at_poisson_cdf;
extern const unary_function_ptr * const  at_poisson_icdf;
extern const unary_function_ptr * const  at_poisson_window;
extern const unary_function_ptr * const  at_polar;
extern const unary_function_ptr * const  at_polar2rectangular;
extern const unary_function_ptr * const  at_polar_coordinates;
extern const unary_function_ptr * const  at_polar_point;
extern const unary_function_ptr * const  at_polarplot;
extern const unary_function_ptr * const  at_pole;
extern const unary_function_ptr * const  at_poly2symb;
extern const unary_function_ptr * const  at_polyEval;
extern const unary_function_ptr * const  at_polygamma;
extern const unary_function_ptr * const  at_polygon;
extern const unary_function_ptr * const  at_polygone_rempli;
extern const unary_function_ptr * const  at_polygonplot;
extern const unary_function_ptr * const  at_polygonscatterplot;
extern const unary_function_ptr * const  at_polyhedron;
extern const unary_function_ptr * const  at_polynomial_regression;
extern const unary_function_ptr * const  at_polynomial_regression_plot;
extern const unary_function_ptr * const  at_pop;
extern const unary_function_ptr * const  at_position;
extern const unary_function_ptr * const  at_poslbdLMQ;
extern const unary_function_ptr * const  at_posubLMQ;
extern const unary_function_ptr * const  at_potential;
extern const unary_function_ptr * const  at_pour;
extern const unary_function_ptr * const  at_pow2exp;
extern const unary_function_ptr * const  at_power_regression;
extern const unary_function_ptr * const  at_power_regression_plot;
extern const unary_function_ptr * const  at_powermod;
extern const unary_function_ptr * const  at_powerpc;
extern const unary_function_ptr * const  at_powexpand;
extern const unary_function_ptr * const  at_powmod;
extern const unary_function_ptr * const  at_prepend;
extern const unary_function_ptr * const  at_preval;
extern const unary_function_ptr * const  at_prevperm;
extern const unary_function_ptr * const  at_prevprime;
extern const unary_function_ptr * const  at_primpart;
extern const unary_function_ptr * const  at_print;
extern const unary_function_ptr * const  at_printf;
extern const unary_function_ptr * const  at_printpow;
extern const unary_function_ptr * const  at_prism;
extern const unary_function_ptr * const  at_prism_graph;
extern const unary_function_ptr * const  at_product;
extern const unary_function_ptr * const  at_prog_eval_level;
extern const unary_function_ptr * const  at_projection;
extern const unary_function_ptr * const  at_proot;
extern const unary_function_ptr * const  at_propFrac;
extern const unary_function_ptr * const  at_propfrac;
extern const unary_function_ptr * const  at_psrgcd;
extern const unary_function_ptr * const  at_ptayl;
extern const unary_function_ptr * const  at_pwd;
extern const unary_function_ptr * const  at_pyramid;
extern const unary_function_ptr * const  at_python;
extern const unary_function_ptr * const  at_python_compat;
extern const unary_function_ptr * const  at_python_list;
extern const unary_function_ptr * const  at_q2a;
extern const unary_function_ptr * const  at_qr;
extern const unary_function_ptr * const  at_quadric;
extern const unary_function_ptr * const  at_quadrilateral;
extern const unary_function_ptr * const  at_quantile;
extern const unary_function_ptr * const  at_quartile1;
extern const unary_function_ptr * const  at_quartile3;
extern const unary_function_ptr * const  at_quartiles;
extern const unary_function_ptr * const  at_quaternion;
extern const unary_function_ptr * const  at_quest;
extern const unary_function_ptr * const  at_quo;
extern const unary_function_ptr * const  at_quorem;
extern const unary_function_ptr * const  at_quote;
extern const unary_function_ptr * const  at_r2e;
extern const unary_function_ptr * const  at_radical_axis;
extern const unary_function_ptr * const  at_radius;
extern const unary_function_ptr * const  at_ramene;
extern const unary_function_ptr * const  at_rand;
extern const unary_function_ptr * const  at_randMat;
extern const unary_function_ptr * const  at_randNorm;
extern const unary_function_ptr * const  at_randPoly;
extern const unary_function_ptr * const  at_randbetad;
extern const unary_function_ptr * const  at_randbinomial;
extern const unary_function_ptr * const  at_randchisquare;
extern const unary_function_ptr * const  at_randchisquared;
extern const unary_function_ptr * const  at_randexp;
extern const unary_function_ptr * const  at_randfisher;
extern const unary_function_ptr * const  at_randfisherd;
extern const unary_function_ptr * const  at_randgammad;
extern const unary_function_ptr * const  at_randgeometric;
extern const unary_function_ptr * const  at_randint;
extern const unary_function_ptr * const  at_randmarkov;
extern const unary_function_ptr * const  at_randmatrix;
extern const unary_function_ptr * const  at_randmultinomial;
extern const unary_function_ptr * const  at_randnormald;
extern const unary_function_ptr * const  at_random;
extern const unary_function_ptr * const  at_random_bipartite_graph;
extern const unary_function_ptr * const  at_random_digraph;
extern const unary_function_ptr * const  at_random_graph;
extern const unary_function_ptr * const  at_random_network;
extern const unary_function_ptr * const  at_random_planar_graph;
extern const unary_function_ptr * const  at_random_regular_graph;
extern const unary_function_ptr * const  at_random_sequence_graph;
extern const unary_function_ptr * const  at_random_tournament;
extern const unary_function_ptr * const  at_random_tree;
extern const unary_function_ptr * const  at_random_variable;
extern const unary_function_ptr * const  at_randperm;
extern const unary_function_ptr * const  at_randpoisson;
extern const unary_function_ptr * const  at_randpoly;
extern const unary_function_ptr * const  at_randrange;
extern const unary_function_ptr * const  at_randstudent;
extern const unary_function_ptr * const  at_randstudentd;
extern const unary_function_ptr * const  at_randvar;
extern const unary_function_ptr * const  at_randvector;
extern const unary_function_ptr * const  at_randweibulld;
extern const unary_function_ptr * const  at_range;
extern const unary_function_ptr * const  at_rank;
extern const unary_function_ptr * const  at_ranm;
extern const unary_function_ptr * const  at_ranv;
extern const unary_function_ptr * const  at_rassembler_trigo;
extern const unary_function_ptr * const  at_rat_jordan;
extern const unary_function_ptr * const  at_rat_jordan_block;
extern const unary_function_ptr * const  at_rationalroot;
extern const unary_function_ptr * const  at_ratnormal;
extern const unary_function_ptr * const  at_rdiv;
extern const unary_function_ptr * const  at_re;
extern const unary_function_ptr * const  at_read;
extern const unary_function_ptr * const  at_readrgb;
extern const unary_function_ptr * const  at_readwav;
extern const unary_function_ptr * const  at_real;
extern const unary_function_ptr * const  at_realproot;
extern const unary_function_ptr * const  at_realroot;
extern const unary_function_ptr * const  at_reciprocation;
extern const unary_function_ptr * const  at_rectangle;
extern const unary_function_ptr * const  at_rectangle_plein;
extern const unary_function_ptr * const  at_rectangular2polar;
extern const unary_function_ptr * const  at_rectangular2spherical;
extern const unary_function_ptr * const  at_rectangular_coordinates;
extern const unary_function_ptr * const  at_recule;
extern const unary_function_ptr * const  at_red;
extern const unary_function_ptr * const  at_redim;
extern const unary_function_ptr * const  at_reduced_conic;
extern const unary_function_ptr * const  at_reduced_quadric;
extern const unary_function_ptr * const  at_ref;
extern const unary_function_ptr * const  at_reflection;
extern const unary_function_ptr * const  at_regroup;
extern const unary_function_ptr * const  at_relabel_vertices;
extern const unary_function_ptr * const  at_reliability_polynomial;
extern const unary_function_ptr * const  at_rem;
extern const unary_function_ptr * const  at_remain;
extern const unary_function_ptr * const  at_remove;
extern const unary_function_ptr * const  at_remove_language;
extern const unary_function_ptr * const  at_reorder;
extern const unary_function_ptr * const  at_repete;
extern const unary_function_ptr * const  at_replace;
extern const unary_function_ptr * const  at_resample;
extern const unary_function_ptr * const  at_reset_solve_counter;
extern const unary_function_ptr * const  at_residue;
extern const unary_function_ptr * const  at_resoudre;
extern const unary_function_ptr * const  at_resoudre_dans_C;
extern const unary_function_ptr * const  at_resoudre_systeme_lineaire;
extern const unary_function_ptr * const  at_restart;
extern const unary_function_ptr * const  at_restart_modes;
extern const unary_function_ptr * const  at_restart_vars;
extern const unary_function_ptr * const  at_resultant;
extern const unary_function_ptr * const  at_reverse;
extern const unary_function_ptr * const  at_reverse_graph;
extern const unary_function_ptr * const  at_reverse_rsolve;
extern const unary_function_ptr * const  at_revert;
extern const unary_function_ptr * const  at_revlist;
extern const unary_function_ptr * const  at_rgb;
extern const unary_function_ptr * const  at_rhombus;
extern const unary_function_ptr * const  at_rhs;
extern const unary_function_ptr * const  at_riemann_window;
extern const unary_function_ptr * const  at_right;
extern const unary_function_ptr * const  at_right_triangle;
extern const unary_function_ptr * const  at_risch;
extern const unary_function_ptr * const  at_rm_a_z;
extern const unary_function_ptr * const  at_rm_all_vars;
extern const unary_function_ptr * const  at_rmbreakpoint;
extern const unary_function_ptr * const  at_rmmod;
extern const unary_function_ptr * const  at_rmwatch;
extern const unary_function_ptr * const  at_romberg;
extern const unary_function_ptr * const  at_rond;
extern const unary_function_ptr * const  at_rootof;
extern const unary_function_ptr * const  at_roots;
extern const unary_function_ptr * const  at_rotate;
extern const unary_function_ptr * const  at_rotatesto;
extern const unary_function_ptr * const  at_rotation;
extern const unary_function_ptr * const  at_round;
extern const unary_function_ptr * const  at_row;
extern const unary_function_ptr * const  at_rowAdd;
extern const unary_function_ptr * const  at_rowDim;
extern const unary_function_ptr * const  at_rowNorm;
extern const unary_function_ptr * const  at_rowSwap;
extern const unary_function_ptr * const  at_rowdim;
extern const unary_function_ptr * const  at_rownorm;
extern const unary_function_ptr * const  at_rowspace;
extern const unary_function_ptr * const  at_rowswap;
extern const unary_function_ptr * const  at_rpn;
extern const unary_function_ptr * const  at_rref;
extern const unary_function_ptr * const  at_rsolve;
extern const unary_function_ptr * const  at_sample;
extern const unary_function_ptr * const  at_samplerate;
extern const unary_function_ptr * const  at_saute;
extern const unary_function_ptr * const  at_sauve;
extern const unary_function_ptr * const  at_save_history;
extern const unary_function_ptr * const  at_scalarProduct;
extern const unary_function_ptr * const  at_scalar_product;
extern const unary_function_ptr * const  at_scale;
extern const unary_function_ptr * const  at_scaleadd;
extern const unary_function_ptr * const  at_scatterplot;
extern const unary_function_ptr * const  at_schur;
extern const unary_function_ptr * const  at_sec;
extern const unary_function_ptr * const  at_sech;
extern const unary_function_ptr * const  at_segment;
extern const unary_function_ptr * const  at_seidel_spectrum;
extern const unary_function_ptr * const  at_seidel_switch;
extern const unary_function_ptr * const  at_select;
extern const unary_function_ptr * const  at_semi_augment;
extern const unary_function_ptr * const  at_seq;
extern const unary_function_ptr * const  at_seqplot;
extern const unary_function_ptr * const  at_seqsolve;
extern const unary_function_ptr * const  at_sequence_graph;
extern const unary_function_ptr * const  at_series;
extern const unary_function_ptr * const  at_set_edge_attribute;
extern const unary_function_ptr * const  at_set_edge_weight;
extern const unary_function_ptr * const  at_set_graph_attribute;
extern const unary_function_ptr * const  at_set_language;
extern const unary_function_ptr * const  at_set_pixel;
extern const unary_function_ptr * const  at_set_vertex_attribute;
extern const unary_function_ptr * const  at_set_vertex_positions;
extern const unary_function_ptr * const  at_shift;
extern const unary_function_ptr * const  at_shift_phase;
extern const unary_function_ptr * const  at_shiftsto;
extern const unary_function_ptr * const  at_shortest_path;
extern const unary_function_ptr * const  at_show;
extern const unary_function_ptr * const  at_show_language;
extern const unary_function_ptr * const  at_show_pixels;
extern const unary_function_ptr * const  at_showturtle;
extern const unary_function_ptr * const  at_shuffle;
extern const unary_function_ptr * const  at_si;
extern const unary_function_ptr * const  at_sialorssinon;
extern const unary_function_ptr * const  at_sierpinski_graph;
extern const unary_function_ptr * const  at_sign;
extern const unary_function_ptr * const  at_signature;
extern const unary_function_ptr * const  at_signe;
extern const unary_function_ptr * const  at_similarity;
extern const unary_function_ptr * const  at_simp2;
extern const unary_function_ptr * const  at_simplex_reduce;
extern const unary_function_ptr * const  at_simplifier;
extern const unary_function_ptr * const  at_simplify;
extern const unary_function_ptr * const  at_simult;
extern const unary_function_ptr * const  at_sin;
extern const unary_function_ptr * const  at_sin2costan;
extern const unary_function_ptr * const  at_sincos;
extern const unary_function_ptr * const  at_single_inter;
extern const unary_function_ptr * const  at_singular;
extern const unary_function_ptr * const  at_sinh;
extern const unary_function_ptr * const  at_sinon;
extern const unary_function_ptr * const  at_size;
extern const unary_function_ptr * const  at_sizes;
extern const unary_function_ptr * const  at_skip;
extern const unary_function_ptr * const  at_sleep;
extern const unary_function_ptr * const  at_slope;
extern const unary_function_ptr * const  at_slopeat;
extern const unary_function_ptr * const  at_slopeatraw;
extern const unary_function_ptr * const  at_smith;
extern const unary_function_ptr * const  at_smod;
extern const unary_function_ptr * const  at_snedecor;
extern const unary_function_ptr * const  at_snedecor_cdf;
extern const unary_function_ptr * const  at_snedecor_icdf;
extern const unary_function_ptr * const  at_snedecord;
extern const unary_function_ptr * const  at_snedecord_cdf;
extern const unary_function_ptr * const  at_snedecord_icdf;
extern const unary_function_ptr * const  at_solve;
extern const unary_function_ptr * const  at_solve_zero_extremum;
extern const unary_function_ptr * const  at_somme;
extern const unary_function_ptr * const  at_sommet;
extern const unary_function_ptr * const  at_sort;
extern const unary_function_ptr * const  at_sorta;
extern const unary_function_ptr * const  at_sortd;
extern const unary_function_ptr * const  at_sorted;
extern const unary_function_ptr * const  at_soundsec;
extern const unary_function_ptr * const  at_spanning_tree;
extern const unary_function_ptr * const  at_speed;
extern const unary_function_ptr * const  at_sphere;
extern const unary_function_ptr * const  at_spherical2rectangular;
extern const unary_function_ptr * const  at_spline;
extern const unary_function_ptr * const  at_split;
extern const unary_function_ptr * const  at_spread2mathml;
extern const unary_function_ptr * const  at_spreadsheet;
extern const unary_function_ptr * const  at_sq;
extern const unary_function_ptr * const  at_sqrfree;
extern const unary_function_ptr * const  at_sqrt;
extern const unary_function_ptr * const  at_square;
extern const unary_function_ptr * const  at_srand;
extern const unary_function_ptr * const  at_sst;
extern const unary_function_ptr * const  at_sst_in;
extern const unary_function_ptr * const  at_st_ordering;
extern const unary_function_ptr * const  at_star_graph;
extern const unary_function_ptr * const  at_stdDev;
extern const unary_function_ptr * const  at_stddev;
extern const unary_function_ptr * const  at_stddevp;
extern const unary_function_ptr * const  at_step_infolevel;
extern const unary_function_ptr * const  at_stereo2mono;
extern const unary_function_ptr * const  at_sto;
extern const unary_function_ptr * const  at_str;
extern const unary_function_ptr * const  at_strassen_limit;
extern const unary_function_ptr * const  at_string;
extern const unary_function_ptr * const  at_strip;
extern const unary_function_ptr * const  at_strongly_connected_components;
extern const unary_function_ptr * const  at_student;
extern const unary_function_ptr * const  at_student_cdf;
extern const unary_function_ptr * const  at_student_icdf;
extern const unary_function_ptr * const  at_studentd;
extern const unary_function_ptr * const  at_studentd_cdf;
extern const unary_function_ptr * const  at_studentd_icdf;
extern const unary_function_ptr * const  at_studentt;
extern const unary_function_ptr * const  at_sturm;
extern const unary_function_ptr * const  at_sturmab;
extern const unary_function_ptr * const  at_sturmseq;
extern const unary_function_ptr * const  at_subMat;
extern const unary_function_ptr * const  at_subdivide_edges;
extern const unary_function_ptr * const  at_subgraph;
extern const unary_function_ptr * const  at_submatrix;
extern const unary_function_ptr * const  at_subst;
extern const unary_function_ptr * const  at_substituer;
extern const unary_function_ptr * const  at_subtype;
extern const unary_function_ptr * const  at_sum;
extern const unary_function_ptr * const  at_sum_riemann;
extern const unary_function_ptr * const  at_suppress;
extern const unary_function_ptr * const  at_surd;
extern const unary_function_ptr * const  at_svd;
extern const unary_function_ptr * const  at_svg;
extern const unary_function_ptr * const  at_svl;
extern const unary_function_ptr * const  at_swapcol;
extern const unary_function_ptr * const  at_swaprow;
extern const unary_function_ptr * const  at_switch_axes;
extern const unary_function_ptr * const  at_sylvester;
extern const unary_function_ptr * const  at_symb2poly;
extern const unary_function_ptr * const  at_syst2mat;
extern const unary_function_ptr * const  at_tCollect;
extern const unary_function_ptr * const  at_tExpand;
extern const unary_function_ptr * const  at_table;
extern const unary_function_ptr * const  at_tablefunc;
extern const unary_function_ptr * const  at_tableseq;
extern const unary_function_ptr * const  at_tabvar;
extern const unary_function_ptr * const  at_tail;
extern const unary_function_ptr * const  at_tan;
extern const unary_function_ptr * const  at_tan2cossin2;
extern const unary_function_ptr * const  at_tan2sincos;
extern const unary_function_ptr * const  at_tan2sincos2;
extern const unary_function_ptr * const  at_tangent;
extern const unary_function_ptr * const  at_tangente;
extern const unary_function_ptr * const  at_tanh;
extern const unary_function_ptr * const  at_tantque;
extern const unary_function_ptr * const  at_taux_accroissement;
extern const unary_function_ptr * const  at_taylor;
extern const unary_function_ptr * const  at_tchebyshev1;
extern const unary_function_ptr * const  at_tchebyshev2;
extern const unary_function_ptr * const  at_tcoeff;
extern const unary_function_ptr * const  at_tcollect;
extern const unary_function_ptr * const  at_tcollectsin;
extern const unary_function_ptr * const  at_tensor_product;
extern const unary_function_ptr * const  at_testfunc;
extern const unary_function_ptr * const  at_tests;
extern const unary_function_ptr * const  at_tetrahedron;
extern const unary_function_ptr * const  at_texpand;
extern const unary_function_ptr * const  at_textinput;
extern const unary_function_ptr * const  at_thiele;
extern const unary_function_ptr * const  at_threads_allowed;
extern const unary_function_ptr * const  at_threshold;
extern const unary_function_ptr * const  at_throw;
extern const unary_function_ptr * const  at_time;
extern const unary_function_ptr * const  at_tlin;
extern const unary_function_ptr * const  at_tonnetz;
extern const unary_function_ptr * const  at_topologic_sort;
extern const unary_function_ptr * const  at_topological_sort;
extern const unary_function_ptr * const  at_torus_grid_graph;
extern const unary_function_ptr * const  at_total_degree;
extern const unary_function_ptr * const  at_tourne_droite;
extern const unary_function_ptr * const  at_tourne_gauche;
extern const unary_function_ptr * const  at_tpsolve;
extern const unary_function_ptr * const  at_trace;
extern const unary_function_ptr * const  at_trail;
extern const unary_function_ptr * const  at_trail2edges;
extern const unary_function_ptr * const  at_tran;
extern const unary_function_ptr * const  at_transitive_closure;
extern const unary_function_ptr * const  at_translation;
extern const unary_function_ptr * const  at_transpose;
extern const unary_function_ptr * const  at_traveling_salesman;
extern const unary_function_ptr * const  at_tree_height;
extern const unary_function_ptr * const  at_triangle;
extern const unary_function_ptr * const  at_triangle_paper;
extern const unary_function_ptr * const  at_triangle_plein;
extern const unary_function_ptr * const  at_triangle_window;
extern const unary_function_ptr * const  at_trig2exp;
extern const unary_function_ptr * const  at_trigcos;
extern const unary_function_ptr * const  at_trigexpand;
extern const unary_function_ptr * const  at_triginterp;
extern const unary_function_ptr * const  at_trigsimplify;
extern const unary_function_ptr * const  at_trigsin;
extern const unary_function_ptr * const  at_trigtan;
extern const unary_function_ptr * const  at_trn;
extern const unary_function_ptr * const  at_trunc;
extern const unary_function_ptr * const  at_truncate;
extern const unary_function_ptr * const  at_truncate_graph;
extern const unary_function_ptr * const  at_tsimplify;
extern const unary_function_ptr * const  at_tukey_window;
extern const unary_function_ptr * const  at_turtle_stack;
extern const unary_function_ptr * const  at_tutte_polynomial;
extern const unary_function_ptr * const  at_two_edge_connected_components;
extern const unary_function_ptr * const  at_type;
extern const unary_function_ptr * const  at_ufactor;
extern const unary_function_ptr * const  at_ugamma;
extern const unary_function_ptr * const  at_unapply;
extern const unary_function_ptr * const  at_unarchive;
extern const unary_function_ptr * const  at_unarchive_ti;
extern const unary_function_ptr * const  at_underlying_graph;
extern const unary_function_ptr * const  at_uniform;
extern const unary_function_ptr * const  at_uniform_cdf;
extern const unary_function_ptr * const  at_uniform_icdf;
extern const unary_function_ptr * const  at_uniformd;
extern const unary_function_ptr * const  at_uniformd_cdf;
extern const unary_function_ptr * const  at_uniformd_icdf;
extern const unary_function_ptr * const  at_unitV;
extern const unary_function_ptr * const  at_unquote;
extern const unary_function_ptr * const  at_upper;
extern const unary_function_ptr * const  at_usimplify;
extern const unary_function_ptr * const  at_valuation;
extern const unary_function_ptr * const  at_vandermonde;
extern const unary_function_ptr * const  at_variance;
extern const unary_function_ptr * const  at_vector;
extern const unary_function_ptr * const  at_vers;
extern const unary_function_ptr * const  at_version;
extern const unary_function_ptr * const  at_vertex_connectivity;
extern const unary_function_ptr * const  at_vertex_degree;
extern const unary_function_ptr * const  at_vertex_distance;
extern const unary_function_ptr * const  at_vertex_in_degree;
extern const unary_function_ptr * const  at_vertex_out_degree;
extern const unary_function_ptr * const  at_vertices;
extern const unary_function_ptr * const  at_vertices_abc;
extern const unary_function_ptr * const  at_vertices_abca;
extern const unary_function_ptr * const  at_vpotential;
extern const unary_function_ptr * const  at_warn_equal_in_prog;
extern const unary_function_ptr * const  at_watch;
extern const unary_function_ptr * const  at_web_graph;
extern const unary_function_ptr * const  at_weibull;
extern const unary_function_ptr * const  at_weibull_cdf;
extern const unary_function_ptr * const  at_weibull_icdf;
extern const unary_function_ptr * const  at_weibulld;
extern const unary_function_ptr * const  at_weibulld_cdf;
extern const unary_function_ptr * const  at_weibulld_icdf;
extern const unary_function_ptr * const  at_weibullvariate;
extern const unary_function_ptr * const  at_weight_matrix;
extern const unary_function_ptr * const  at_welch_window;
extern const unary_function_ptr * const  at_whattype;
extern const unary_function_ptr * const  at_wheel_graph;
extern const unary_function_ptr * const  at_when;
extern const unary_function_ptr * const  at_white;
extern const unary_function_ptr * const  at_widget_size;
extern const unary_function_ptr * const  at_wilcoxonp;
extern const unary_function_ptr * const  at_wilcoxons;
extern const unary_function_ptr * const  at_wilcoxont;
extern const unary_function_ptr * const  at_with_sqrt;
extern const unary_function_ptr * const  at_write;
extern const unary_function_ptr * const  at_writergb;
extern const unary_function_ptr * const  at_writewav;
extern const unary_function_ptr * const  at_wz_certificate;
extern const unary_function_ptr * const  at_xcas;
extern const unary_function_ptr * const  at_xcas_mode;
extern const unary_function_ptr * const  at_xorsto;
extern const unary_function_ptr * const  at_xyztrange;
extern const unary_function_ptr * const  at_yellow;
extern const unary_function_ptr * const  at_zeros;
extern const unary_function_ptr * const  at_zip;
extern const unary_function_ptr * const  at_ztrans;
extern const unary_function_ptr * const  at_DELTALIST;
extern const unary_function_ptr * const  at_PILIST;
extern const unary_function_ptr * const  at_HPSUM;
extern const unary_function_ptr * const  at_SIGMALIST;
extern const unary_function_ptr * const  at_HPDIFF;
extern const unary_function_ptr * const  at_polar_complex;
extern const unary_function_ptr * const  at_HPINT;
}
#endif // STATIC_EXTERN
